@@ -24,6 +24,9 @@ class VolumioListener:
     def on_favourite_updated(self, stationname: str):
         pass
 
+    def on_albumart_updated(self, albumart_uri):
+        pass
+
 
 
 class Volumio(VolumioListener):
@@ -37,6 +40,7 @@ class Volumio(VolumioListener):
         self.__playing = False
         self.__title = ""
         self.__artist = ""
+        self.__albumart = ""
         self.__favourites = []
         self.__favourite = {}
 
@@ -68,6 +72,10 @@ class Volumio(VolumioListener):
     def favourite_station(self, station: str):
         self.play_favourite(station)
 
+    @property
+    def albumart(self):
+        return self.__albumart
+
     @property
     def title(self):
         return self.__title
@@ -120,6 +128,10 @@ class Volumio(VolumioListener):
     def on_favourite_updated(self, stationname: str):
         self.__listener.on_favourite_updated(stationname)
 
+    def on_albumart_updated(self, albumart):
+        if albumart != self.__albumart:
+            self.__albumart = albumart
+            self.__listener.on_albumart_updated(albumart)
 
     def sync_state(self):
         response = requests.get(self.volumio_base_uri + 'api/v1/getstate')
@@ -131,6 +143,10 @@ class Volumio(VolumioListener):
                 self.on_artist_updated(data['artist'])
             if 'title' in data.keys():
                 self.on_title_updated(data['title'])
+            albumart = data.get('albumart', '')
+            if albumart.startswith("/"):
+                albumart = self.volumio_base_uri[:-1] + albumart
+            self.on_albumart_updated(albumart)
         else:
             logging.warning("could not get state. Got " + response.text)
 
@@ -152,14 +168,14 @@ class Volumio(VolumioListener):
     def play(self):
         response = requests.get(self.volumio_base_uri + "api/v1/commands/?cmd=play")
         if self.is_success(response):
-            logging.debug("start playing")
+            logging.info("start playing")
         else:
             logging.warning("could not start playing. Got " + response.text)
 
     def stop(self):
         response = requests.get(self.volumio_base_uri + "api/v1/commands/?cmd=stop")
         if self.is_success(response):
-            logging.debug("stop playing")
+            logging.info("stop playing")
         else:
             logging.warning("could not stop playing. Got " + response.text)
 
@@ -168,7 +184,7 @@ class Volumio(VolumioListener):
             if favourite['title'] == station:
                 response = requests.post(self.volumio_base_uri + 'api/v1/replaceAndPlay', json.dumps(favourite), headers={'Content-Type': 'application/json'})
                 if self.is_success(response):
-                    logging.debug("playing station '" + station + "' ")
+                    logging.info("playing station '" + station + "' ")
                 else:
                     logging.warning("could set station " + station + ". Got " + response.text)
                 return
@@ -179,3 +195,8 @@ class Volumio(VolumioListener):
 
     def play_previous_favourite(self):
         pass
+
+
+
+
+volumio = Volumio('http://10.1.33.30:3000')
\ No newline at end of file
